// https://nuxt.com/docs/api/configuration/nuxt-config
import postcsspxtoviewport from 'postcss-px-to-viewport'

export default defineNuxtConfig({
  app: {
    // baseURL: "beta.cocorobo.cn",
    head: {
      title: '可可乐博STEAM教育',
      charset: 'utf-8',
      viewport: 'width=device-width,initial-scale=1',
      meta: [
        { name: 'keywords', content: '可可乐博，STEAM教育，STEM教育，智能硬件编程，图形化编程，可视化编程，创客教育，科创教育，AI人工智能教育，在线教育，在线直播' },
        { name: 'description', content: '可可乐博（CocoRobo）是一家专注于STEAM领域的教育科技公司，以自主研发的硬件、课程套件、软件工具、学习平台为基础，专注于特色STEAM课程研发及面向中小学生的名师授课服务' }
      ]
    },
    pageTransition: { name: 'page', mode: 'out-in' }
  },
  // devServer: {
  //   port: 80,
  //   host: 'beta.cocorobo.cn'
  // },
  plugins: ['@/plugins/rem.js'],
  css: ['@/assets/css/main.scss'],
  // 跨域
  nitro: {
    devProxy: {
      '/api': {
        target: '*',
        changeOrigin: true,
      }
    }
  },
  vite: {
    css: {
      postcss: {
        plugins: [
          postcsspxtoviewport({
            unitToConvert: 'px', // 要转化的单位
            viewportWidth: 1920, // UI设计稿的宽度
            unitPrecision: 6, // 转换后的精度，即小数点位数
            propList: ['*'], // 指定转换的css属性的单位，*代表全部css属性的单位都进行转换
            viewportUnit: 'vw', // 指定需要转换成的视窗单位，默认vw
            fontViewportUnit: 'vw', // 指定字体需要转换成的视窗单位，默认vw
            selectorBlackList: ['el-'], // 指定不转换为视窗单位的类名,例如van-（vantUI组件），
            minPixelValue: 1, // 默认值1，小于或等于1px则不进行转换
            mediaQuery: true, // 是否在媒体查询的css代码中也进行转换，默认false
            replace: true, // 是否转换后直接更换属性值
            exclude: [/node_modules/], // 设置忽略文件，用正则做目录名匹配，最好不要排除node_modules 文件，排除后在项目中会发现字体不能跟随页面放大
            landscape: false // 是否处理横屏情况
          })
        ]
      }
    }
  }
})